@@ -788,30 +788,12 @@ world <- function(xrange, yrange, landscape = "naturalearth", crs = NULL,
     # the small scale Natural Earth data is bundled with slendr
     ne_dir <- file.path(tempdir(), "naturalearth")
     if (scale == "small") {
-      utils::unzip(system.file("naturalearth/ne_110m_land.zip", package = "slendr"),
-                   exdir = ne_dir)
+      utils::unzip(system.file("naturalearth/ne_110m_land.zip", package = "slendr"), exdir = ne_dir)
     } else {
-      size <- ifelse(scale == "large", 10, 50)
-      file <- sprintf("ne_%sm_land.zip", size)
-      if (!dir.exists(ne_dir)) dir.create(ne_dir)
-      path <- file.path(ne_dir, file)
-      utils::download.file(
-        url = sprintf("https://naturalearth.s3.amazonaws.com/%sm_physical/%s", size, file),
-        destfile = path, quiet = TRUE
-      )
-      utils::unzip(path, exdir = ne_dir)
+      rnaturalearth::ne_download(scale = scale, type = "land", category = "physical", destdir = ne_dir, load = FALSE)
     }
 
-    # TODO: this function uses internally rgdal, which is to be retired by 2023
-    # silence the deprecation warning for now, as it would only confuse the user
-    # and figure out a way to deal with this (either by providing a PR to the devs
-    # or hacking our own alternative)
-    suppressWarnings(
-      map_raw <- rnaturalearth::ne_load(
-        scale = scale, type = "land", category = "physical",
-        returnclass = "sf", destdir = ne_dir
-      )
-    )
+    map_raw <- rnaturalearth::ne_load(scale = scale, type = "land", category = "physical", destdir = ne_dir)
     sf::st_agr(map_raw) <- "constant"
 
     # define boundary coordinates in the target CRS
@@ -1257,6 +1239,13 @@ schedule_sampling <- function(model, times, ..., locations = NULL, strict = FALS
   sample_pops <- purrr::map(samples, 1)
   sample_counts <- purrr::map(samples, 2)
 
+  model_names <- vapply(model$populations, function(pop) pop$pop[1], FUN.VALUE = "character")
+  sample_names <- vapply(sample_pops, function(pop) pop$pop[1], FUN.VALUE = "character")
+  missing_names <- setdiff(sample_names, model_names)
+  if (length(missing_names))
+    stop("The following sampled populations are not part of the model: ",
+         paste(missing_names, collapse = ", "), call. = FALSE)
+
   if (is.null(model$world) && !is.null(locations))
     stop("Sampling locations may only be specified for a spatial model", call. = FALSE)
 
@@ -1351,12 +1340,14 @@ schedule_sampling <- function(model, times, ..., locations = NULL, strict = FALS
 #'
 #' @export
 init_env <- function(quiet = FALSE) {
-  if (!is_slendr_env_present())
+  if (!check_dependencies(python = TRUE))
     stop("Could not activate slendr's Python environment because it is not\npresent ",
          "on your system ('", PYTHON_ENV, "').\n\n",
          "To set up a dedicated Python environment you first need to run setup_env().", call. = FALSE)
   else {
-    reticulate::use_condaenv(PYTHON_ENV, required = TRUE)
+    # reticulate::use_condaenv(PYTHON_ENV, required = TRUE)
+    python_path <- slendr::get_python()
+    reticulate::use_python(python_path, required = TRUE)
 
     # this is an awful workaround around the reticulate/Python bug which prevents
     # import_from_path (see zzz.R) from working properly -- I'm getting nonsensical
@@ -1391,6 +1382,20 @@ init_env <- function(quiet = FALSE) {
   }
 }
 
+#' Get a path to internal Python interpreter of slendr
+#'
+#' @return A character scalar path to slendr's Python binary
+#'
+#' @export
+get_python <- function() {
+  env_path <- file.path(reticulate::miniconda_path(), "envs", PYTHON_ENV)
+  if (Sys.info()["sysname"] == "Windows")
+    python_path <- normalizePath(file.path(env_path, "python.exe"), winslash = "/", mustWork = FALSE)
+  else
+    python_path <- file.path(env_path, "bin", "python")
+  python_path
+}
+
 #' Setup a dedicated Python virtual environment for slendr
 #'
 #' This function will automatically download a Python miniconda distribution
@@ -1528,12 +1533,6 @@ clear_env <- function(force = FALSE, all = FALSE) {
   }
 }
 
-#' Get the name of the current slendr Python environment
-#'
-#' @return Name of the slendr Python environment
-get_env <- function() {
-  PYTHON_ENV
-}
 
 #' Check that the active Python environment is setup for slendr
 #'
