@@ -28,10 +28,10 @@ check_dependencies <- function(python = FALSE, slim = FALSE, quit = FALSE) {
 
   if (fail) {
     if (interactive()) {
-      error_slim <- if (missing_slim) "SLiM" else ""
-      error_python <- if (missing_python) "slendr Python environment" else ""
-      stop(sprintf("Missing requirements for this example: %s",
-                   paste(error_slim, error_python, sep = ", ")), call. = FALSE)
+      error_slim <- if (missing_slim) "  - SLiM binary not found in the path" else ""
+      error_python <- if (missing_python) "  - Python environment (did you run setup_env()?)" else ""
+      stop(sprintf("Missing requirements of slendr:\n%s\n%s",
+                   error_slim, error_python), call. = FALSE)
     } else {
       if (quit)
         q()
@@ -728,10 +728,11 @@ ask_install <- function(module) {
 }
 
 is_slendr_env_present <- function() {
-  tryCatch({
-    PYTHON_ENV %in% reticulate::conda_list()$name
-  }, error = function(cond) FALSE
-  )
+  # tryCatch({
+  #   PYTHON_ENV %in% reticulate::conda_list()$name
+  # }, error = function(cond) FALSE
+  # )
+  file.exists(get_python())
 }
 
 is_slim_present <- function() {
