@@ -1,4 +1,4 @@
-skip_if(!is_slendr_env_present())
+skip_if(!check_dependencies(python = TRUE))
 init_env(quiet = TRUE)
 
 test_that("only serialized models can be run on the command line", {
